<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Microsoft.Windows.Widgets.Providers

Windows Runtime (WinRT) APIs for for the `Microsoft.Windows.Widgets.Providers` namespace.

This package provides the `winrt.microsoft.windows.widgets.providers` module.
